@@ -1,8 +1,8 @@
 """ example subject """
+
 import datetime
 
-from aind_data_schema import Subject
-from aind_data_schema.subject import Housing
+from aind_data_schema.subject import Housing, Subject
 
 t = datetime.datetime(2022, 11, 22, 8, 43, 00)
 
